#include "mex.h"

void r6solver(double bondAL[6][2], double hand[4][4], 
	      int *nresult, double result[6][16]); 


#define MAXRES 16 /* max number of solutions */

/* The gateway routine *
 * Copied from the MATLAB documentation:: External Interfaces/API: Creating C Language MEX-Files: Passing Two or More Inputs or Outputs
 *
 * This function sets up the input and output variables 
 * and checks that they are ok.
 *  Note: matrices are in COLUMN-MAJOR order from MATLAB, 
    so this function must do transpositions, (unless we avoid them
    by defining the inputs to the C function as the transpose...)
 */


void mexFunction( int nlhs, mxArray *plhs[],
                  int nrhs, const mxArray *prhs[])
{
  double *bondAL; /*bondAL[2][6] (COL-MAJ) is first input arg: bond angles and lengths */
  double *hand; /*hand[4][4] (COL-MAJ) is second input arg: hand matrix, last row (0 0 0 1)*/
  double *outM; /* output matrix, built from */
  int nresult; /* actual number of solutions */
  double result[6][MAXRES]; /* and solution phi,psi angles (ROW-MAJOR)*/
  int     i,j,k;
  
  /*  Check for proper number of arguments. */
  /* NOTE: You do not need an else statement when using
     mexErrMsgTxt within an if statement. It will never
     get to the else statement if mexErrMsgTxt is executed.
     (mexErrMsgTxt breaks you out of the MEX-file.) 
 */
  if(nrhs!=2) 
    mexErrMsgTxt("Two inputs required.");
  if(nlhs!=1) 
    mexErrMsgTxt("One output required.");
  
   /* Check matrix type and dimensions */
  if( (!mxIsDouble(prhs[0])) || mxGetM(prhs[0])!=2 || mxGetN(prhs[0]) != 6 ) {
    mexErrMsgTxt("First input must be 2x6 matrix of real bond angles and lengths.");
  }
  if( (!mxIsDouble(prhs[1])) || mxGetM(prhs[1])!=4 || mxGetN(prhs[1]) != 4 ) {
    mexErrMsgTxt("Second input must be 4x4 hand matrix (last row 0 0 0 1)");
  }

  /*  Create pointers to input matrices. */
  bondAL = mxGetPr(prhs[0]);
  hand = mxGetPr(prhs[1]);
  
  /* Do the work */
  r6solver(bondAL, hand, &nresult, result);

  /*  Create output matrix as 6 x nresult. */
  plhs[0] = mxCreateDoubleMatrix(6,nresult, mxREAL);
  
  /*  Create a C pointer to a copy of the output matrix. */
  outM = mxGetPr(plhs[0]);
  
  /* Copy the result matrix to output matrix */
  k = 0;
  for (i = 0; i < nresult; i++)
    for (j = 0; j< 6; j++)
      outM[k++] = result[j][i]; //  COLUMN MAJOR 6 x nresult for return
}
	      

     
