/* 
This file contains the routine for reading the input parameter for the 
given robot. It consists of the fixes parameters like length of links,
offsets, twist angles and the RHS matrix for the inverse kinematics.


We use Fortran routine for reading, since there seems to be a problem in 
reading double precision input using a C compiler.
*/


#include <stdio.h>
#include "function.h"
#include <math.h>
#define SCALE 1.0

/*
    The global variables. Follow mostly to Raghavan/Roth paper.
*/

/*
     The L's are the cosines and M's are the sines of the twist angles.
*/
    extern coordinate L1,L2,L3,L4,L5,L6;
    extern coordinate M1,M2,M3,M4,M5,M6;

/*
      a_i is the length of link i.

      d_i is the offset distance of joint i;
*/
    extern coordinate AA1,AA2,AA3,AA4,AA5,AA6;
    extern coordinate D_d1,D_d2,D_d3,D_d4,D_d5,D_d6;

/*
    These are the entries of the RHS matrix.

      [ lx  mx nx qx ]
      [ ly  my ny qy ]
      [ lz  mz nz qz ]
      [ 0   0  0  1  ]

*/
    extern coordinate lx,ly,lz,mx,my,mz,nx,ny,nz,qx,qy,qz;
    extern coordinate Pi;


//Read_Example(coordinate* al1, coordinate* al2, coordinate* al3, coordinate* al4, coordinate* al5, coordinate* al6)
Read_Example(double bondAL[6][2], double hand[4][4])
{

    coordinate al1, al2, al3, al4, al5, al6;
    coordinate A1[4][4], A2[4][4], A3[4][4], A4[4][4], A5[4][4], A6[4][4];
    coordinate t1,t2,t3,t4,t5,t6;

    coordinate C1, C2, C3, C4, C5, C6;
    coordinate S1, S2, S3, S4, S5, S6;
    double Temp;

    coordinate sum, LHS[4][4], temp[4][4], temp1[4][4];

    int i,j,k,seed;

	 int argcindex = 1;

		AA1 = AA2 = AA3 = AA4 = AA5 = AA6 = 0;
 
		D_d1 = bondAL[0][0];
		D_d2 = bondAL[1][0];
		D_d3 = bondAL[2][0];
		D_d4 = bondAL[3][0];
		D_d5 = bondAL[4][0];
		D_d6 = bondAL[5][0];
 
		al1 = bondAL[0][1]*M_PI/180.0; /* convert to radians */
		al2 = bondAL[1][1]*M_PI/180.0;
		al3 = bondAL[2][1]*M_PI/180.0;
		al4 = bondAL[3][1]*M_PI/180.0;
		al5 = bondAL[4][1]*M_PI/180.0;
		al6 = bondAL[5][1]*M_PI/180.0;

    L1 = cos(al1 );
    L2 = cos(al2 );
    L3 = cos(al3 );
    L4 = cos(al4 );
    L5 = cos(al5 );
    L6 = cos(al6 );

    M1 = sin(al1 );
    M2 = sin(al2 );
    M3 = sin(al3 );
    M4 = sin(al4 );
    M5 = sin(al5 );
    M6 = sin(al6 );

	lx = hand[0][0];
	mx = hand[1][0];
	nx = hand[2][0];
	ly = hand[0][1];
	my = hand[1][1];
	ny = hand[2][1];
	lz = hand[0][2];
	mz = hand[1][2];
	nz = hand[2][2];
	qx = hand[3][0];
	qy = hand[3][1];
	qz = hand[3][2];

}

