function loop = chooseLoop(protResCoords, wiggleRes, wiggleCase)
% loop = chooseLoop(protResCoords, wiggleRes, 
% this function begins to create the loop object that we will work on.
% It determines the coordinates coords, residues, 
% atom type numbers (n=1,ca=2,c=3) & angle/length parameters.
% Currently there are two types of loops: 2cb loops which are the beta
% hairpin turns that wiggle two Cbetas, and centralCb loops which wiggle
% the central Cbeta and two adjacent.

loop.type = lower(wiggleCase); % save case name as loop type: expect '2cb' or centralCb
prevResid = find(protResCoords(:,1) == wiggleRes-1); % find which atoms contribute coordinates
if length(prevResid) ~= 3
    error(['In chosing loop, residue ' num2str(wiggleRes-1) ' does not have three atoms on backbone.']);
end
prevResid = prevResid(1); % first (=N) atom of previous residue.
if strcmp(loop.type, '2cb') % we have a beta hairpin wiggle
    range = prevResid+(0:11); % take atoms from four consecutive residues (first 2 and last 2 don't move)
else % wiggle central Cbeta
    range = prevResid+(-1:9); % take three consecutive residues + two more atoms for start & end frames
end
loop.startAtom = range(1)-1; % record the starting atom index from original protein; for writeKin only.
loop.resNo = protResCoords(range,1); % for writeKin only
loop.original = 1; % index of original loop is changed in wiggleLoop; used in plot, etc.
loop.solnCount = 1; % changed in wiggleLoop and loopBranches; used in plot, etc.

loop.coords = protResCoords(range,2:4); 
loop.atomTypeNo = mod(range+2,3)+1; % transform indices to atom type numbers (n=1,ca=2,c=3).
loop.params = coords2Params(loop.coords); % get DH parameters for this chain
loop.sidecoords = makeSideCoords(loop);
