function A = DH(params)
% A = dh([theta, alpha, d, a]) four parameter Denavit-Hartenburg
% transformation for molecules.  theta=dihedral ang (degrees), 
% alpha=bond ang (degrees), d = bond len, a = offset 
% Return rotation matrix A that will postmultiply a frame to transform. 
% (The parameter a is optional, and defaults to zero.)
%
% In proteins, the initial frame will point with the z axis along the next bond,
% with the previous bond angle is in the yz plane. 
%
% The transformation translates along the z axis by d (bond length), 
% then rotates about the z axis by theta (dihedral),
% then rotates aobut the x axis by alpha (bond angle),
% then translates along the x axis by a (offset).

error('Called DH, which I thought was for documentation only. (computation inlined in coords2Params)');

if length(params) < 4
    a = 0;
else
    a = params(4);
end
torad = pi/180;
C = cos(params(1)*torad);
S = sin(params(1)*torad);
L = cos(params(2)*torad);
M = sin(params(2)*torad);

A = [C -S*L   S*M  a*C;
     S  C*L  -C*M  a*S;
     0   M     L   params(3);
     0   0     0   1];
 
