%for ik work, we need to replace the peptides C & N with closest points P1 & P2.
[ppChain, cnMult] = peptideToOffset(loop.atomTypeNo, loop.coords); % save multipliers for later recovery
[ikOriginal, junk] = offsetToIk(loop.atomTypeNo, ppChain(:,:,loop.original));

startFrame = makeFrame(ikOriginal(1:3,:));
targetFrame = startFrame \ makeFrame(ikOriginal(end-2:end,:)); % target if we start with eye(4)

kk = size(ppChain,3);
for k = 1:kk
    % get Ik Geom = 6x4 = [dih ang, bond ang, bond len, offset]
    [ikChain, ikGeom] = makeOffsetParams(loop.atomTypeNo, ppChain(:,:,k));
    ikSolution = r6solverdeg(ikGeom(:,[4 3 2]), targetFrame);
    
    mm = size(ikSolution,2);
    solnIkParams = ikGeom(:,:,ones(mm,1)); % copies of DH4 params
    for m = 1:mm
        solnIkParams(:,1,m) = ikSolution(:,m); % replace dihedrals with solution.
    end
    
    solnChain = DHToCoords(solnIkParams, ikOriginal); % build all solution coordinates
    solnQ = zeros(mm,1);
    for m = 1:mm
        d = norm(ikOriginal(end-2:end,:) - solnChain(end-2:end,:,m));
        if (d < 1e-4) % hits target
            solnQ(m) = norm(ikOriginal - solnChain(:,:,m)); % how close to original?
        else
            fprintf('bad solution %d,%d with norm %g\n', k, m, d);
            solnQ(m) = 1e64; % bad solution is one that misses targetFrame
        end
    end
    
    [solnQ, ind] = sort(solnQ);
    ind = ind(solnQ < 1e64);
    if isempty(ind)
        fprintf('No good solutions for %d.\n',k);
        solnCoords = [];
    else
        solnIkParams = solnIkParams(:, :, ind);
        solnChain = solnChain(:, :, ind);
    end
  
    solnppChain = ikToOffset(loop.atomTypeNo, solnIkParams, ppChain)
    solnCoords  = offsetToPeptide(loop.atomTypeNo, solnppChain, cnMult);

end



%% for each solution branch build all Atom chain and write kin
[coordMatrix, atomList] = makeSideCoords(loop.atomTypeNo, chain);
writeKin(filenameKin, wiggleRes, solIndex, coordMatrix, atomList, 'w', 1); 
for i = 1:numSol
    [coordMatrix, atomList] = getSideCoords(numOper, s,  operFcnHdl, aaCoordsMat(:,:,i));
    writeKin(filenameKin, resName, s, numOper, wiggleRes, solIndex, coordMatrix, atomList, 'a', i+1, 'branch'); 
end



ppChain = DHoffset(loop.atomTypeNo, loop.coords);
loop.startFrame = makeFrame(ppChain(1:3,:)) 
loop.targetFrame = loop.startFrame \ makeFrame(ppChain(end-2:end,:));
[ikChain,geom] = getOffsetParams(ppChain);

frame = makeFrame(coords(1:3,:));
for i = 1:size(geom,1)
    targetFrame = targetFrame*dh4(geom(i,1), geom(i,2), geom(i,3), geom(i,4));
end;

targetFrame-loop.targetFrame



phiPsiInd = 1+find(loop.atomTypeNo(2:end-1)~=2); %indices of phi and psi
if (length(phiPsiInd) ~= 6) 
    error('phiPsiInd is wrong in loopBranches');
end

mm = size(ikSolution,2);
    p = loop.params(:,:,k,ones(mm,1)); % copies of params
    for m = 1:mm
        p(phiPsiInd,1,k,m) = ikSolution(:,m);
    end
    c = DHToCoords(squeeze(p), loop.coords(:,:,k));
    