function [aaDihBranch, deltaInfo, directionMatrix, normMatrix] = anyWiggle4(rbp, loopLength, wiggleRes, aaModIndex, dind, deltaAngName, vColor)

% JSS: use tables or pass strings so the code is self-documenting.
% avoid magic numbers

%                    2/b1 3pep1/b2   4/t2  5/b3 6pep2/b4
idealAngTable =[-999 -999  180    -999  -999 180;
               -999 116.2 121.7  111.2 116.2 121.7];

idealAng = idealAngTable(dind,aaModIndex);
if idealAng == -999
    error('invalid input arguments for delta indices');
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% vColor = {'red';'orange'; 'yellow'; 'gold'; 'lime'; 'purple'};
% aaModIndex = 4; dind = 2; deltaAngName = 'tau2'; idealAng = 111.2; vColor{5};
deltaMin = -3;
deltaMax = -deltaMin;
deltaStep = 0.25;
totalSteps = (deltaMax-deltaMin)/deltaStep+1;
scale = 2; % multiplicative scale for der vector length
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% JSS: You have four or five different ways of recording whether you are doing 1cb or 2cb.
%%      Watch it to make sure they agree...  Don't do the numOper and s
%%      assignments so far in advance.

if (loopLength == 11)
    inputChain = rbp(3*(wiggleRes-2):3*(wiggleRes+1)+1,:);
    s = 1;
    numOper = 8;
elseif (loopLength == 12)
    inputChain = rbp(3*(wiggleRes-2)+1:3*(wiggleRes+2),:);  % sets wiggle res = cbeta1 in two cbeta loop
    s = 2;
    numOper = 9;
end;

% here we a chain of backbone atoms, 
% s pointing to 
% and numOper indicating 
% JSS: firstN removed; not used

three = 1:3;
chain = inputChain(:,three+1); % remove col1 = residue number
lengthofChain = length(chain);

operFcnHdl = [@oper_n2h, @oper_ca2cb,  @oper_c2o];
aaGeom = coords2Params(chain); % get original chain geom (in degrees)
[ppChain, time] = offsetPlanarize(chain); % convert Ca.c.n.Ca chain to Ca.p1.p2.Ca chain

ppGeom = coords2Params(ppChain); % (in degrees)
lengthofppChain = length(ppChain);

% get Ik Geom = 6x4 = [dih ang, bond ang, bond len, offset]
[ikChain, ikGeom] = getOffsetParams(ppChain);
lengthofIkChain = length(ikChain);
lengthIkGeom = length(ikGeom);

deltaAng = aaGeom(aaModIndex,dind)-idealAng;

filenameKin1 = sprintf('res%d_%dcb_%sBranches.kin',wiggleRes, s, deltaAngName);
filenameKin2 = sprintf('res%d_%dcb_%sDeltaCoords.kin',wiggleRes, s, deltaAngName);
varFileName1 = sprintf('res%d_%dcb_%sBranchCoords.mat', wiggleRes, s, deltaAngName);
varFileName2 = sprintf('res%d_%dcb_%sCoords.mat', wiggleRes, s, deltaAngName);
varFileName3 = sprintf('res%d_%dcb_%sDihs.mat', wiggleRes, s, deltaAngName);
resName = 'ala';

ppChain(1:3,:)-chain(1:3,:)

% get starting frame
z0 = ppChain(3,:)-ppChain(2,:);
z0 = z0/norm(z0);
prevBond = ikChain(1,:)-ikChain(2,:);
prevBond = prevBond/norm(prevBond);
x0 = cross(prevBond,z0); x0 = x0/norm(x0);
y0 = cross(z0,x0); y0 = y0/norm(y0);
startFrame = [x0', y0', z0', ikChain(2,:)'; 0 0 0 1];
 
% get Ik Frame
geom = ikGeom;
geom(:,1:2) = geom(:,1:2)*pi/180; % convert dihs and bond angs to radians 
targetFrame = eye(4);
for i = 1:lengthIkGeom
    targetFrame = targetFrame*dh4(geom(i,1), geom(i,2), geom(i,3), geom(i,4));
end;

% get ik solutions (returns good solutions only)
[ikSolutions, ikCoordsMat, aaCoordsMat] = getIkSolution(numOper, ikChain, ikGeom(:,2:4), aaGeom(:,3), startFrame, targetFrame, time);
numSol = size(ikSolutions,2);

% verify solutions contain original
diff = ones(numSol,1);
for i = 1:numSol  diff(i) = norm(ikSolutions(:,i)-ikGeom(:,1)); end;
solIndex = find(diff < 1e-4);
if isempty(solIndex)  fprintf('orig dih do not match any r6solver sols'); end;
ppoff = norm(ppChain(:,:)- ikCoordsMat(:,:,solIndex));
aaoff = norm(chain(:,:)- aaCoordsMat(:,:,solIndex));
coordMatch = 1;
if (ppoff > 1e-4) fprintf('sol and orig ikCoords not equal, %f \n', off); end;
if (aaoff > 1e-4) coordMatch = 0; fprintf('sol and orig aaCoords not equal \n'); end;

%% for each solution branch build all Atom chain and write kin
[coordMatrix, atomList] = getSideCoords(numOper, s,  operFcnHdl, chain);
writeKin(filenameKin1, resName, s, numOper, wiggleRes, solIndex, coordMatrix, atomList, 'w', 1); 
for i = 1:numSol
    [coordMatrix, atomList] = getSideCoords(numOper, s,  operFcnHdl, aaCoordsMat(:,:,i));
    writeKin(filenameKin1, resName, s, numOper, wiggleRes, solIndex, coordMatrix, atomList, 'a', i+1, 'branch'); 
end; 

% intialize for delta loop
ikDeltaDihedrals = zeros(6,1,totalSteps);
aaDeltaDihedrals = zeros(numOper,1,totalSteps);
aaDeltaGeomSol = zeros(numOper,3,1,totalSteps);
ikDeltaCoordsMat = zeros(lengthofChain,3,1,totalSteps);  % (pp coords)
aaDeltaCoordsMat = zeros(lengthofChain,3,1,totalSteps);
aaDihBranch = zeros(numOper,1,totalSteps); % for reordered dihs
ikDihBranch = zeros(6,1,totalSteps);       % for reordered dihs
aaCoordsMatOrder = zeros(lengthofChain, 3, 1, totalSteps); % reordered coords
numDeltaSol = zeros(totalSteps,1);

% intialize for delta loop
atomListMat = zeros(2*(numOper+1),3,1,totalSteps); % atomListMat = hold coord info for derivative computation
endDots = zeros(1, 3, totalSteps);                 % endDots =  collect coords for second to last atom
deltaDots = zeros(1,3,totalSteps);                 % deltaDots =  collect coords for sidechain atom corresponding to delta oper

% DELTA LOOP (get iksolutions, ikcoords, aacoords)
stepNum = 0;
newCount = 0;
lastLeg = norm(chain(end,:)-chain(end-1,:));
for ii = deltaMin:deltaStep:deltaMax
    stepNum = stepNum+1;
    
    % get new Coords and new ikGeom
    geom = aaGeom;
    geom(aaModIndex,dind) = geom(aaModIndex, dind) + ii;
    testGeom = geom;
    geom(:,2) = geom(:,2)+180;
    geom(:,1:2) = geom(:,1:2)*pi/180; % convert dihs and bond angs to radians 
    newFrame = startFrame;
    newChain = zeros(lengthofChain,3);
    newChain(1:2,:) = chain(1:2,:);
    for j = 1:numOper
        newFrame = newFrame*dh4(geom(j,1), geom(j,2), geom(j,3), 0);
        newChain(j+2,:) = newFrame(three,4)';
    end;
    newChain(j+3,:) = (newFrame(three,:)*[0; 0; lastLeg; 1])';
    aanewGeom = coords2Params(newChain); % just a check 
    [ppnewChain, newtime] = offsetPlanarize(newChain);
    [iknewChain, iknewGeom] = getOffsetParams(ppnewChain);
    
    % get ik solutions
    ikALa = iknewGeom(:,2:4); % reset ikALa 
    [ikSolutions, ikCoordsMat, aaCoordsMat] = getIkSolution(numOper, ikChain, ikALa, aaGeom(:,3), startFrame, targetFrame, newtime);
    
    numDeltaSol(stepNum) = size(ikSolutions,2);    
    if (numDeltaSol(stepNum) > 0)
   %   fprintf('stepNum = %d, delta = %f, yields %g solution branches \n', stepNum, ii, numDeltaSol(stepNum));
       colList = 1:numDeltaSol(stepNum);
       
       % store info returned from getIkSolution
       ikDeltaDihedrals(:,colList,stepNum) = ikSolutions;
       ikDeltaCoordsMat(:,:,colList,stepNum) = ikCoordsMat;
       aaDeltaCoordsMat(:,:,colList,stepNum) = aaCoordsMat;
       for j = 1:numDeltaSol(stepNum)
           aaDeltaGeomSol(:,:,j,stepNum) = coords2Params(aaCoordsMat(:,:,j));
       end;
       store = aaDeltaGeomSol(:,1,colList,stepNum);  store = squeeze(store);
       aaDeltaDihedrals(:,colList,stepNum) = store;       
       
       % organize solutions
       [ikDihBranch,aaDihBranch,aaCoordsMatOrder] = orderSolution(stepNum, numDeltaSol, ikDihBranch, aaDihBranch, ikDeltaDihedrals, aaDeltaDihedrals, aaCoordsMat);

       %% for each solution branch build all Atom chain and collect dots
       [branchInd] = find(aaDihBranch(1,:,stepNum));
       for j = 1:length(branchInd)
           [coordMatNew, atomListNew] = getSideCoords(numOper, s,  operFcnHdl, aaCoordsMatOrder(:,:,branchInd(j), stepNum));
           endDots(branchInd(j),:,stepNum) = atomListNew(2*numOper-1,:); % collect end dots
           deltaDots(branchInd(j),:,stepNum) = atomListNew(2*(aaModIndex+1),:); % collect sidechain delta dots
           atomListMat(:,:,branchInd(j),stepNum) = atomListNew;  % collect atom info for derivative
           coordMat(:,:,:,branchInd(j),stepNum) = coordMatNew;  % collect atom info for derivative
       end;
   else
       fprintf('\t stepNum = %d, delta = %f, yields %g solution branches \n', stepNum, ii, numDeltaSol(stepNum));
   end; % if sol > 0 loop
end; % delta loop

% RECORD COORDS FOR ALL BRANCH (and write coords to mat file)
if deltaMin < 0
    stepstoZero = deltaMin:deltaStep:0;
    zeroStepNum = length(stepstoZero);  % find stepNum for delta = 0
else
    zeroStepNum = 1;
end;
[non0BranchesDelta0] = find(ikDihBranch(1,:,zeroStepNum));
numberofBranches = length(non0BranchesDelta0);

% record branch coords delta = 0
resNumList = repmat(inputChain(:,1),1,2);
resNumList = reshape(resNumList',2*(lengthofChain),1);
resNumList([1 2 end-1 end]) = [];
resNumList = repmat(resNumList,1, numberofBranches);
aaBranchCoords = zeros(2*(lengthofChain-2),4, numberofBranches);
aaBranchCoords(:,three+1,:) = squeeze(atomListMat(:,:,non0BranchesDelta0,zeroStepNum));
aaBranchCoords(:,1,:) = resNumList;
save(varFileName1, 'aaBranchCoords');

% record delta coords for all branches
for j = 1:numberofBranches % at delta = 0
    [non0Steps] = find(atomListMat(1,1,non0BranchesDelta0(j),:));
    lengthofNon0Steps = length(non0Steps);
    resNumList = repmat(inputChain(:,1),1,2);
    resNumList = reshape(resNumList',2*lengthofChain,1);
    resNumList([1 2 end-1 end]) = [];
    resNumList = repmat(resNumList,1, lengthofNon0Steps);
    aaModBranchCoords = zeros(2*(lengthofChain-2),4,lengthofNon0Steps);
    aaModBranchCoords(:,three+1,:) = squeeze(atomListMat(:,:,non0BranchesDelta0(j),non0Steps));
    aaModBranchCoords(:,1,:) = resNumList;
    varFileName = sprintf('res%d_%dcb_%sCoordsBranch%d.mat', wiggleRes, s, deltaAngName, non0BranchesDelta0(j));
    save(varFileName, 'aaModBranchCoords');
end;
    
% record delta coords for original branch 
for i = 1:numberofBranches
    diff(non0BranchesDelta0(i)) = norm(ikDihBranch(:,non0BranchesDelta0(i),zeroStepNum)-ikGeom(:,1)); 
end;
solIndex = find(diff(non0BranchesDelta0) < 1e-4);    
[non0Steps] = find(atomListMat(1,1,solIndex,:));
lengthofNon0Steps = length(non0Steps);
resNumList = repmat(inputChain(:,1),1,2);
resNumList = reshape(resNumList',2*lengthofChain,1);
resNumList([1 2 end-1 end]) = [];
resNumList = repmat(resNumList,1, lengthofNon0Steps);
aaModCoords = zeros(2*(lengthofChain-2),4,lengthofNon0Steps);
aaModCoords(:,three+1,:) = squeeze(atomListMat(:,:,solIndex,non0Steps));
aaModCoords(:,1,:) = resNumList;
save(varFileName2, 'aaModCoords');

branchDeltaMin = deltaMin + deltaStep*(non0Steps(1)-1);
branchDeltaMax = deltaMin + deltaStep*(non0Steps(lengthofNon0Steps)-1);
deltaInfo = [solIndex, deltaAng, branchDeltaMin, branchDeltaMax, deltaStep];
save(varFileName3, 'aaDihBranch', 'solIndex', 'deltaInfo');

%% for each delta of original branch write kin
writeKin(filenameKin2, resName, s, numOper, wiggleRes, solIndex, coordMat(:,:,:,solIndex,zeroStepNum), aaModCoords(:,2:4,1), 'w', 1); 
for j = 1:lengthofNon0Steps
    writeKin(filenameKin2, resName, s, numOper, wiggleRes, solIndex, coordMat(:,:,:,solIndex,non0Steps(j)), aaModCoords(:,2:4,j), 'a', j+1, 'step'); 
end; 

% DERIVATIVE CALCULATION (and write kinemage)
if deltaAng > 0
    scale = -scale; % vectors point towards ideal.
end;
maxBranchNum = max(numDeltaSol);
for bindex = 1:numberofBranches 
    j = non0BranchesDelta0(bindex);
    stepInd = find(ikDihBranch(1,j,:)); % find the stepNums with solutions for the jth branch 
    lengthofStepInd = length(stepInd);
    if (lengthofStepInd > 4)
        if (ikDihBranch(1,j,zeroStepNum)== 0)
            centerInd = stepInd(floor(lengthofStepInd/2)+1); % kin coords for this branch are from centerInd stepnum (so may not be plotted at delta=0
        else 
            centerInd = zeroStepNum;
        end;
        
        d = (deltaMin:deltaStep:deltaMax)';
        d = d(stepInd);
        lengthofD = length(d);
        t = ones(lengthofD,1);
        D = [t d d.^2];  
        
        slope = zeros(2*(numOper+1),3);
        xyz = zeros(3,lengthofD);
        for k = 1:2*(numOper+1)  % computes derivative for each atom using quadratic approximation
            xyz = atomListMat(k,:,j,stepInd); 
            xyz = squeeze(xyz)';
            S = D\xyz;
            slope(k,:) = [S(2,1) S(2,2) S(2,3)];
        end;
        
        dVectors = slope;  
        numVectors = size(dVectors,1);
        tauVector = dVectors(9,:);
        relativeDir = zeros(numVectors,1);
        norms = zeros(numVectors,1);
        for k = 1:numVectors  
            relativeDir(k) = sign(dot(dVectors(k,:),tauVector));
            norms(k) = relativeDir(k)*norm(dVectors(k,:)); 
        end;
        normMatrix(:,bindex) = norms;
        directionMatrix(:,bindex) = relativeDir;
        ndVectors = dVectors*scale;
        filenameKinD = sprintf('res%d_%dcb_%sDeriv_Branch%d.kin', wiggleRes,s, deltaAngName, j);
        dotsE = squeeze(endDots(j,:,stepInd));
        dotsE = dotsE';
        dotsD = squeeze(deltaDots(j,:,stepInd));
        dotsD = dotsD';
        writeKinD(filenameKinD, resName, s, numOper, wiggleRes, j, deltaAngName, coordMat(:,:,:,j,centerInd), atomListMat(:,:,j,centerInd), ndVectors, norms, dotsE, dotsD, vColor)
    end;
end;

directionMatrix = directionMatrix(:,solIndex);
normMatrix = normMatrix(:,solIndex);
