function geom = coordsToDH3(chain)
% chain is an (n+2)x3 matrix of coords 
% calculates dihedral, angle, and length for DH on corresponding bond
% returns an (n-1)x3 matrix of [dih, bond ang, bond len] 

deg = 180/pi;
numAtoms = length(chain);
numBonds = numAtoms-1;
bonds = zeros(numBonds,3);
bondLengths = zeros(numBonds,1);
bondAngles = zeros(numBonds,1);
dih = zeros(numBonds,1);

for i = 1:(numBonds)
    bond(i,:) = chain(i+1,:)-chain(i,:);
    bondLengths(i) = norm(bond(i,:));
    bond(i,:) = bond(i,:)./bondLengths(i);
end;

bondAngles(1) = acos(dot(bond(2,:),-bond(1,:)))*deg;  % convert to degrees

for i = 2:(numBonds-1)
    bondAngles(i) = acos(dot(bond(i+1,:),-bond(i,:)))*deg;  % convert to degrees
    y = cross(bond(i-1,:),bond(i,:));
    y = y/norm(y);
    x = cross(y,bond(i,:));
    x = x/norm(x);
    x = dot(bond(i+1,:),x);
    y = dot(bond(i+1,:),y);
    dih(i) = atan2(y,x)*deg;
%    if (bondAngles(i) < 90) dih(i) = dih(i) - 180; end;
end;

if (offsetFlag)
geom = zeros(numBonds,3);
geom(:,1) = dih;
geom(:,2) = bondAngles;
geom(:,3) = bondLengths;
geom = geom(2:numBonds-1,:);    
