function [ikChain, geom] = getOffsetParams(atomTypeNo, chain)
% function [ikChain, geom] = getOffsetParams(chain)
% chain is an (n+2)x3 matrix of coords 
% calculates dihedral, angle, and length for DH on corresponding bond
% returns an (n-1)x3 matrix of [dih, bond ang, bond len, a] 

numAtoms = length(chain);
if (numAtoms == 11)
    firstN = 2;
elseif (numAtoms == 12)
    firstN = 1;
else
    error('incorrect chain length');
end
deg = 180/pi;
numBonds = numAtoms-1;

bond = diff(chain); % compute all vectors and normalize
bondLengths = sqrt(sum(bond.^2,2)); % get all lengths
bond = bond ./ bondLengths(:,[1 1 1], :, :); % normalize

% record offset parameter (a) and remove P1->P2 info from bond info
firstCa = 1+mod(firstN,3);
Cas = find(atomTypeNo(1:end-3) == 2); % list indices of all Calphas except last one.
Cs = firstCa+1:3:numBonds-2;

a = zeros(6,1);
offsetVec = zeros(8,3);
ikChain = chain;
ikBond = bond;

a(firstN:2:5) = bondLengths(Cs);
bondLengths(Cs) = [];
ikChain(Cs,:) = [];
ikBond(Cs,:) = [];
offsetVec(firstCa:2:6,:) = bond(Cs,:); % 
offsetVec(firstCa+1:2:7,:) = bond(Cs,:);

% 11 atoms -> was 10 bonds -> removed 2 -> 8 bonds -> 6 full params to come
% 12 atoms -> was 11 bonds -> removed 3 -> 8 bonds -> 6 full params to come

numIkBonds = length(ikBond);
bondAngles = zeros(numIkBonds,1);
dih = zeros(numIkBonds,1);

bondAngles(1) = acos(dot(ikBond(2,:),-ikBond(1,:)))*deg;  % convert to degrees
for i = 2:(numIkBonds-1)
    bondAngles(i) = acos(dot(ikBond(i+1,:),-ikBond(i,:)))*deg;  % convert to degrees
    bondAngles(i) = bondAngles(i)+180;  % why? and why not to the first one?  
    
    dih(i) = computeDihedral(ikBond(i-1:i+1,:))*deg; % convert to degrees

    crossCheck = cross(-ikBond(i,:),ikBond(i+1,:)); % x vector
    if dot(crossCheck, offsetVec(i,:)) < 0
        a(i-1) = -a(i-1);
    end;
end;

geom = zeros(numIkBonds-2,4);
geom(:,1) = dih(2:numIkBonds-1);
geom(:,2) = bondAngles(2:numIkBonds-1);
geom(:,3) = bondLengths(2:numIkBonds-1);
geom(:,4) = a;
        