function [chain, time] = offsetPlanarize(chain)
% function chain = offsetPlanarize(chain, firstn) returns coordinates of a chain 
% with the C and N converted to the offset points P1 and P2.  

count = 1;
firstCa = 1+mod(firstN,3);

for Ca = firstCa:3:numAtoms-3
    vec1 = chain(Ca+1,:)-chain(Ca,:); % Calpha1 - C
    vec2 = chain(Ca+2,:)-chain(Ca+3,:); % Calpha2 - N
    vec3  = chain(Ca,:)-chain(Ca+3,:); % Calpha2 - Calpha1
    
    dot12 = dot(vec1,vec2);
    A = [-dot(vec1,vec1)  dot12;   -dot12,    dot(vec2,vec2)];
    B = [dot(vec1,vec3); dot(vec2,vec3)]; %%% A*t = B;
    t = A\B;
    time(count,:) = t';
    
    P1 = chain(Ca,:) + t(1)*vec1;
    P2 = chain(Ca+3,:) + t(2)*vec2;
    
    vecP = P2-P1;
    if (dot(vec1,vecP)> 1e-9) error('p1,p2 calculation not accurate'); end;
    if (dot(vec2,vecP)> 1e-9) error('p1,p2 calculation not accurate'); end;
    
%     vecN = chain(Ca-1,:) - chain(Ca,:);
%     vecN = cross(-vec1,vecN);
%     vecN = vecN/norm(vecN);
%     vecP = vecP/norm(vecP);
%     one = dot(vecP,vecN);
    count = count+1;
    chain(Ca+1:Ca+2,:) = [P1; P2];
end

