function kin = writeKin(filenameKin, resName, startAtom, numOper, wiggleRes, solIndex, coordMatrix, atomList, writeOption, kinNum, buttonLabel)

s = startAtom;
atomNum = 1;  % starting atom number for Kin file

if (s == 1)
    atomNumN = wiggleRes-1;
    atomNumCA = wiggleRes-1; 
    atomNumC = wiggleRes-1;
    atomNumBB = wiggleRes-1;
elseif ( s == 2)
    atomNumN = wiggleRes;
    atomNumCA = wiggleRes-1;
    atomNumC = wiggleRes-1;
    atomNumBB = wiggleRes-1;
end;

if (s==1)
    atomListNames = [' n  '; ' h  '; ' ca '; ' cb '; ' c  ';' o  '];
    bbPointLine = [' L '; ' L '; ' L '; ' L '; ' L '; ' L '];
elseif (s==2)
    atomListNames = [' ca '; ' cb '; ' c  ';' o  '; ' n  '; ' h  '];
    bbPointLine = [' L '; ' L '; ' L '; ' L '; ' L '; ' L '; ' L '];
else
    atomListNames = [' c  ';' o  '; ' n  '; ' h  '; ' ca '; ' cb '];
    bbPointLine = [' L '; ' L '; ' L '; ' L '; ' L '; ' L '; ' L '];
end;

numAtomList = size(atomList,1);
numCycles = floor(numOper/3)+1;

numN = numCycles;
numH = numCycles;
numCa = numCycles;
numCb = numCycles;
numC = numCycles;
numO = numCycles;

pointN = zeros(numCycles,3);
pointCa = zeros(numCycles,3);
pointC = zeros(numCycles,3);
pointH = zeros(numCycles,3);
pointCb = zeros(numCycles,3);
pointO = zeros(numCycles,3);

for i = 1:numCycles
    pointN(i,:) = coordMatrix(1,i,:);
    pointCa(i,:) = coordMatrix(2,i,:);
    pointC(i,:) = coordMatrix(3,i,:);
    pointH(i,:) = coordMatrix(4,i,:);
    pointCb(i,:) = coordMatrix(5,i,:);
    pointO(i,:) = coordMatrix(6,i,:);
end;

zeroV = [0 0 0];
if isequal(pointN(numCycles,:),zeroV)
    pointN(numCycles,:) = [];
    numN = numCycles-1;
end;
if isequal(pointCa(numCycles,:),zeroV)
    pointCa(numCycles,:) = [];
    numCa = numCycles-1;
end;
if isequal(pointC(numCycles,:),zeroV)
    pointC(numCycles,:) = [];
    numC = numCycles-1;
end;
if isequal(pointH(numCycles,:),zeroV)
    pointH(numCycles,:) = [];
    numH = numCycles-1;
end;
if isequal(pointCb(numCycles,:),zeroV)
    pointCb(numCycles,:) = [];
    numCb = numCycles-1;
end;
if isequal(pointO(numCycles,:),zeroV)
    pointO(numCycles,:) = [];
    numO = numCycles-1;
end;

if (size(resName,2) == 3)
    resName = [' ', resName];
end
    
if (nargin > 8) 
    if (kinNum == 1)
        fid = fopen(filenameKin, 'w');
        outstring = sprintf('@kinemage %g \n', kinNum);
        outstring = [outstring, sprintf('@group {original %g}',solIndex), '\n'];
    else
        fid = fopen(filenameKin, writeOption);
        outstring = sprintf('@group {%s %g } \n', buttonLabel, (kinNum-1));
    end;
else
    fid = fopen(filenameKin, 'w');
    kinNum=1;
    outstring = sprintf('@kinemage %g \n', kinNum);
    outstring = [outstring, '\n @pdbfile {} \n'];
    outstring = [outstring, '@onewidth \n'];
    outstring = [outstring, '@zoom 1.00 \n'];
    outstring = [outstring, '@zslab 200 \n'];
    outstring = [outstring, '@ztran 0 \n'];
    outstring = [outstring, '@matrix \n'];
    outstring = [outstring, '1.000000 0.000000 0.000000 0.000000 1.000000 0.000000 0.000000 0.000000 1.000000 \n'];
    outstring = [outstring, sprintf('@group {original %g}',solIndex), '\n'];
end

% MAINCHAIN
outstring = [outstring, '@subgroup {mainchain} dominant\n'];
outstring = [outstring, '@balllist {N} color = blue master = {mainchain} radius = 0.05 \n'];
fprintf(fid, outstring); 
for i = 1:numN
		outstring =  '{';
       	outstring = [outstring,' n '];
   	    outstring = [outstring,sprintf('%4s', resName)];
        outstring = [outstring, sprintf('%5d', i - 1 + atomNumN)];
   	    outstring = [outstring, ' } '];
       	outstring = [outstring,sprintf('%6f,', pointN(i,1))];
   	    outstring = [outstring,sprintf('%6f,', pointN(i,2))];
   	    outstring = [outstring,sprintf('%6f', pointN(i,3)), '\n'];
        fprintf(fid, outstring);        
end
outstring = [outstring, '@balllist {C} color = grey master = {mainchain} radius = 0.05 \n'];
fprintf(fid, outstring);  
for i = 1:numC
		outstring =  '{';
       	outstring = [outstring,' c  '];
   	    outstring = [outstring,sprintf('%4s', resName)];
        outstring = [outstring, sprintf('%5d', i - 1 + atomNumC)];
   	    outstring = [outstring, ' } '];
       	outstring = [outstring,sprintf('%6f,', pointC(i,1))];
   	    outstring = [outstring,sprintf('%6f,', pointC(i,2))];
   	    outstring = [outstring,sprintf('%6f', pointC(i,3)), '\n'];
        fprintf(fid, outstring);        
end
outstring = [outstring, '@balllist {CA} color = grey master = {mainchain} radius = 0.05 \n'];
fprintf(fid, outstring); 
for i = 1:numCa
		outstring =  '{';
       	outstring = [outstring,' ca  '];
   	    outstring = [outstring,sprintf('%4s', resName)];
        outstring = [outstring, sprintf('%5d', i - 1 + atomNumCA)];
   	    outstring = [outstring, ' } '];
       	outstring = [outstring,sprintf('%6f,', pointCa(i,1))];
   	    outstring = [outstring,sprintf('%6f,', pointCa(i,2))];
   	    outstring = [outstring,sprintf('%6f', pointCa(i,3)), '\n'];
        fprintf(fid, outstring);        
end
outstring = [outstring, '@balllist {O} color = red master = {mainchain} radius = 0.05 \n'];
fprintf(fid, outstring);
for i = 1:numO
		outstring =  '{';
       	outstring = [outstring,' o  '];
   	    outstring = [outstring,sprintf('%4s', resName)];
        outstring = [outstring, sprintf('%5d', i - 1 + atomNumC)];
   	    outstring = [outstring, ' } '];
       	outstring = [outstring,sprintf('%6f,', pointO(i,1))];
   	    outstring = [outstring,sprintf('%6f,', pointO(i,2))];
   	    outstring = [outstring,sprintf('%6f', pointO(i,3)), '\n'];
        fprintf(fid, outstring);        
end
outstring = [outstring, '@vectorlist {mc} color = white master = {mainchain} \n'];
fprintf(fid, outstring);
index = 0;
for i = 1:2:numAtomList
        index = index+1;
		outstring = '{';
       	outstring = [outstring,atomListNames(mod(i-1,6)+1,:)];
   	    outstring = [outstring,sprintf('%4s', resName)];
        outstring = [outstring, sprintf('%5d', index - 1 + atomNumBB)];
   	    outstring = [outstring, ' }   '];
       	outstring = [outstring,bbPointLine(mod(i-1,6)+1,:)];
        outstring = [outstring,sprintf('%6f,', atomList(i,1))];
   	    outstring = [outstring,sprintf('%6f,', atomList(i,2))];
   	    outstring = [outstring,sprintf('%6f', atomList(i,3)), '\n'];
   	    fprintf(fid,outstring);
end
outstring = [outstring, '@vectorlist {co} color= white  master= {mainchain} \n'];
fprintf(fid,outstring);
for i = 1:numO
		outstring =  '{';
       	outstring = [outstring,' c '];
   	    outstring = [outstring,sprintf('%4s', resName)];
        outstring = [outstring, sprintf('%5d', i - 1 + atomNumC)];
       	outstring = [outstring, ' }  P '];
        outstring = [outstring,sprintf('%6f,', pointC(i,1))];
   	    outstring = [outstring,sprintf('%6f,', pointC(i,2))];
   	    outstring = [outstring,sprintf('%6f', pointC(i,3)), '\n'];
       	outstring = [outstring, ' {  '];
        outstring = [outstring,' o '];
   	    outstring = [outstring,sprintf('%4s', resName)];
        outstring = [outstring, sprintf('%5d', i - 1 + atomNumC)];
   	    outstring = [outstring, ' } L '];
        outstring = [outstring,sprintf('%6f,', pointO(i,1))];
   	    outstring = [outstring,sprintf('%6f,', pointO(i,2))];
   	    outstring = [outstring,sprintf('%6f', pointO(i,3)), '\n'];
   	    fprintf(fid,outstring);
end
% HYDROGENS
outstring = [outstring, '@vectorlist {mc H} color= gray lens master= {mainchain} \n'];
fprintf(fid,outstring);
for i = 1:numH
		outstring =  '{';
       	outstring = [outstring,' n '];
   	    outstring = [outstring,sprintf('%4s', resName)];
        outstring = [outstring, sprintf('%5d', i - 1 + atomNumN)];
   	    outstring = [outstring, ' } P '];
       	outstring = [outstring,sprintf('%6f,', pointN(i,1))];
   	    outstring = [outstring,sprintf('%6f,', pointN(i,2))];
   	    outstring = [outstring,sprintf('%6f', pointN(i,3)), '\n'];
		outstring = [outstring,'{'];
       	outstring = [outstring,' h '];
   	    outstring = [outstring,sprintf('%4s', resName)];
        outstring = [outstring, sprintf('%5d', i - 1 + atomNumN)];
   	    outstring = [outstring, ' } L '];
        outstring = [outstring,sprintf('%6f,',pointH(i,1))];
   	    outstring = [outstring,sprintf('%6f,', pointH(i,2))];
   	    outstring = [outstring,sprintf('%6f', pointH(i,3)), '\n'];
   	    fprintf(fid,outstring);
end

% SIDECHAIN
outstring = [outstring, '@subgroup {sidechain} dominant\n'];
outstring = [outstring, '@balllist {CB} color = cyan radius = 0.05 \n'];
fprintf(fid, outstring);
for i = 1:numCb
		outstring =  '{';
       	outstring = [outstring,' cb  '];
   	    outstring = [outstring,sprintf('%4s', resName)];
        outstring = [outstring, sprintf('%5d', i - 1 + atomNumCA)];
   	    outstring = [outstring, ' } '];
       	outstring = [outstring,sprintf('%6f,', pointCb(i,1))];
   	    outstring = [outstring,sprintf('%6f,', pointCb(i,2))];
   	    outstring = [outstring,sprintf('%6f', pointCb(i,3)), '\n'];
        fprintf(fid, outstring);        
end
outstring = [outstring, '@vectorlist {sc} color= cyan  \n'];
fprintf(fid,outstring);
for i = 1:numCb
		outstring =  '{';
       	outstring = [outstring,' ca '];
   	    outstring = [outstring,sprintf('%4s', resName)];
        outstring = [outstring, sprintf('%5d', i - 1 + atomNumCA)];
       	outstring = [outstring, ' }  P '];
        outstring = [outstring,sprintf('%6f,', pointCa(i,1))];
   	    outstring = [outstring,sprintf('%6f,', pointCa(i,2))];
   	    outstring = [outstring,sprintf('%6f', pointCa(i,3)), '\n'];
       	outstring = [outstring, ' {  '];
        outstring = [outstring,' cb '];
   	    outstring = [outstring,sprintf('%4s', resName)];
        outstring = [outstring, sprintf('%5d', i - 1 + atomNumCA)];
   	    outstring = [outstring, ' } L '];
        outstring = [outstring,sprintf('%6f,', pointCb(i,1))];
   	    outstring = [outstring,sprintf('%6f,', pointCb(i,2))];
   	    outstring = [outstring,sprintf('%6f', pointCb(i,3)), '\n'];
   	    fprintf(fid,outstring);
end

fclose(fid);
	