function result = computeDihedral(M)
% result = dihedral(M) takes a sequence of vectors u to v to w as rows of M, 
% computes the dihedral angle in radians (-pi,pi] for projecting -u and w onto 
% the plane perp to v, then rotating -u ccw to w. The vectors need not be normalized.
% If starting with coordinates P in rows, simply computeDihedral(diff(P))

u = M(1,:);
v = M(2,:);
w = M(3,:);
y = cross(u,v); % makes normal to uv plane
y = y/norm(y);
x = cross(y,v); % makes projection of u perp to v
x = x/norm(x);  % this gives coord system for rotation of plane perp to v
x = dot(w,x);   % find w's projection onto this plane
y = dot(w,y);
result = atan2(y,x); % return angle
