function [ikSolutions, ikCoordsMat] = getIkSolution(ikGeom, targetFrame)
% ikGeom is 6x3 [ang, len, offset]
% JSS: time is

three = 1:3;
lengthofIkChain = length(ikChain); 
lengthofChain = numOper+3; % add starting atom and one atom on either end

ikaLA = fliplr(ikGeom);
ikSolutions = r6solverdeg(ikaLA, targetFrame);
numSol = size(ikSolutions,2);
% if (numSol == 0) fprintf('no dihedral solutions found by r6solver'); end;

% initialize for rebuild loop
ikCoordsMat = zeros(lengthofChain,3, numSol);
aaCoordsMat = zeros(lengthofChain,3,numSol);
numBad = 0;
indexofBadSol = [];
geom = zeros(6,4);

% rebuild chain for each branch solution (both ikChain and all atom chain)
for i = 1:numSol
    frame = startFrame; % reset start frame

    ikCoordsMat(1,:,i) = ikChain(1,:); % stores first atom (C/N) always fixed
    ikCoordsMat(2,:,i) = frame(three,4); % stores second atom (N/Ca) always fixed
    ikCoordsMat(lengthofChain,:,i) = ikChain(lengthofIkChain,:); % stores last atom (N/C) always fixed
    
    aaCoordsMat(1,:,i) = ikChain(1,:); % stores first atom (C/N) always fixed
    aaCoordsMat(2,:,i) = frame(three,4); % stores second atom (N/Ca) always fixed
    aaCoordsMat(lengthofChain,:,i) = ikChain(lengthofIkChain,:); % stores last atom (N/C) always fixed
    aaIndex = 11-numOper;
    
    geom = [ikSolutions(:,i) ikGeom];
    geom(:,1:2) = geom(:,1:2)*pi/180;
    
    if (numOper == 8)
        aaIndex = 3;
        direction = ones(numOper,1);
        direction(2,1) = sign(time(1,1));
        direction(5,1) = sign(time(2,1));
        for j = 1:6
            frame = frame*dh4(geom(j,1), geom(j,2), geom(j,3), geom(j,4));
            if (mod(j,2) == 1)  % j = 1,3,5 makes Calpha coord frame
                ikCoordsMat(aaIndex,:,i) = frame(three,4);
                aaCoordsMat(aaIndex,:,i) = frame(three,4);
                ikCoordsMat(aaIndex+1, :, i) = frame(three,:)*[0 0 geom(j+1,3) 1]';
                aaCoordsMat(aaIndex+1, :, i) = frame(three,:)*[0 0 direction(aaIndex-1,1)*aaLen(aaIndex-1,1) 1]';
                aaIndex = aaIndex+2;
            elseif (j < 6) % j = 2, 4 makes peptide point frame
                ikCoordsMat(aaIndex,:,i) = frame(three,4);
                aaCoordsMat(aaIndex, :, i) = frame(three,:)*[0 0 (geom(j+1,3)-aaLen(aaIndex-1,1)) 1]';
                aaIndex = aaIndex+1;
            elseif (j==6) % j = 6 goes from last Ca to last C
                ikCoordsMat(aaIndex-1,:,i) = frame(three,4);
                aaCoordsMat(aaIndex-1, :, i) = frame(three,4); % gets last C atom
            end;
        end;
    elseif (numOper == 9)
        aaIndex = 2;
        direction = ones(numOper,1);
        direction(1,1) = sign(time(1,1));
        direction(4,1) = sign(time(2,1));
        direction(7,1) = sign(time(3,1));
        for j = 1:6
            if (mod(j,2) == 1) % Calpha frame. j will make peptide point frame
                ikCoordsMat(aaIndex, :, i) = frame(three,4);
                aaCoordsMat(aaIndex,:,i) = frame(three,4);
                ikCoordsMat(aaIndex+1, :, i) = frame(three,:)*[0 0 geom(j,3) 1]';
                aaCoordsMat(aaIndex+1, :, i) = frame(three,:)*[0 0 direction(aaIndex-1,1)*aaLen(aaIndex-1,1) 1]';
                aaIndex = aaIndex+2;
            else % pep point frame, j will make calpha frame
                ikCoordsMat(aaIndex, :, i) = frame(three,4);
                aaCoordsMat(aaIndex, :, i) = frame(three,:)*[0 0 (geom(j,3)-aaLen(aaIndex-1,1)) 1]';
                aaIndex = aaIndex+1;
            end;
            frame = frame*dh4(geom(j,1), geom(j,2), geom(j,3), geom(j,4));
        end;
        ikCoordsMat(aaIndex, :, i) = frame(three,4);
        aaCoordsMat(aaIndex, :, i) = frame(three,4);
    end;
    
    % check frames match
    frameofsolution =  inv(startFrame)*frame;
    var1 = norm(targetFrame-frameofsolution);
    [ikBranchCoords, ikBranchGeom] = getOffsetParams(ikCoordsMat(:,:,i));
    var2 = norm(ikBranchGeom(1:5,2:4)-ikGeom(1:5,:));  % only check 1:5 right now.  last bond angle has to be fixed.
    if (var1 > 1e-2) 
        fprintf('frames do not match for %d\n', i);
        numBad = numBad+1;
        indexofBadSol(numBad) = i;
    elseif (var2 > 1e-4)
        fprintf('geoms do not match %d\n', i);
    end;
end;

ikCoordsMat(:,:,indexofBadSol) = [];
aaCoordsMat(:,:,indexofBadSol) = [];
ikSolutions(:,indexofBadSol) = [];