function params = coords2Params(chain)
% chain is an (n+2)x3 matrix of coords 
% calculates dihedral, angle, and length for DH on corresponding bond
% returns an (n-1)x3 matrix of [dih, bond ang, bond len] 

deg = 180/pi;
numAtoms = size(chain,1);
kk = size(chain,3);
numBonds = numAtoms-1;
params = zeros([numBonds-1,3,kk]);

bond = diff(chain);
bondLengths = squeeze(sqrt(sum(bond.^2,2)));
for k = 1:kk
    for i = 1:numBonds
        bond(i,:,k) = bond(i,:,k)./bondLengths(i,k);
    end;
    params(:,3,k) = bondLengths(2:numBonds,k);
    for i = 2:(numBonds-1)
        params(i-1,2,k) = computeBondDHAngle(bond(i:i+1,:,k))*deg;  % convert to degrees
        params(i-1,1,k) = computeDihedral(bond(i-1:i+1,:,k))*deg;
    end;
end
