function A = dh4(theta, alpha, d, a)
% A = dh4(theta, alpha, d, a) four parameter Denavit-Hartenburg transformation 
% theta=dihedral ang, alpha=bond ang, d = bond len, a = offset
% Return rotation matrix A that will postmultiply a frame to transform. 
%
% In proteins, the initial frame has the z axis along the next bond, and
% the previous bond angle is in yz plane with positive projection on y.
%
% The transformation translates along the z axis by d (bond length), 
% then rotates about the z axis by theta (dihedral),
% then rotates about the x axis by alpha (bond angle),
% then translates along the x axis by a (offset).

C = cos(theta);
S = sin(theta);
L = cos(alpha);
M = sin(alpha);

A = [C -S*L   S*M  a*C;
     S  C*L  -C*M  a*S;
     0   M     L   d;
     0   0     0   1];
 
