function origFrame = getOriginalFrame(pN,pCA,pC, baNCB, baCCB, NsideDihed, CsideDihed)
%getOriginalFrame is a backbone specific frame creating function, pointing the zaxis along the Ca-Cb bond.
%This function uses the Richardson described method of building the c-beta bond vector from the N and then
%from the C backbone atom's perspective, using a precalculated dihedral from each side.  Glycine is not handled
%The first three parameters are row vectors.
%The last four parameters are angles in radians, the baNCB is the ideal N-CA-CB angle, baCCB corresponds to 
%the C-CA-CB bond angle.  The two dihedrals also come from ideal bond geometries.

%global ibg;
%degToRad = pi/180;

vcan  = pN - pCA;
nvcan = vcan / norm(vcan);
nvnca = -nvcan;

vcac  = pC - pCA;
nvcac = vcac / norm(vcac);
nvcca = -nvcac;

pnvcac = nvcac - dot(nvcac,nvcan)*nvcan;
yaxisN  = pnvcac / norm(pnvcac);

pnvcan = nvcan - dot(nvcan, nvcac)*nvcac;
yaxisC = pnvcan / norm(pnvcan);

xaxisN  = cross(yaxisN, nvnca);
xaxisC  = cross(yaxisC, nvcca);

%ibgBA_NCAC  = degToRad * ibg.bondAngle{ibg.ch1e}(ibg.nh1,ibg.c);
%ibgBA_NCACB = degToRad * ibg.bondAngle{ibg.ch1e}(ibg.nh1,ibg.ch2e);
%ibgBA_CBCAC = degToRad * ibg.bondAngle{ibg.ch1e}(ibg.ch2e,ibg.c);
%ibgBL_CACB  = ibg.bondLength(ibg.ch1e,ibg.ch2e);

%idealNDihed = calcDihedralFromThreeBondAngles(baNC, baNCB, baCCB);
%idealCDihed = calcDihedralFromThreeBondAngles(baNC, baCCB, baNCB);

NFrame      = [[xaxisN, 0]' [yaxisN, 0]' [nvnca 0]' [pCA 1]'];
CFrame      = [[xaxisC, 0]' [yaxisC, 0]' [nvcca 0]' [pCA 1]'];

ToCBFromN   = NFrame * dh4(-1 * NsideDihed, baNCB - pi, 0,0);
ToCBFromC   = CFrame * dh4(CsideDihed, baCCB - pi, 0, 0);

% ToCBFromN   = NFrame * Rz(-1 * NsideDihed) * Rx(baNCB - pi);
% ToCBFromC   = CFrame * Rz(CsideDihed) * Rx(baCCB - pi);

selectZ = [0; 0; 1; 0];

AveZAxis    = ToCBFromN * selectZ + ToCBFromC * selectZ;
navezax     = (AveZAxis(1:3) / norm(AveZAxis(1:3)))';

yaxisA      = nvcan - dot(nvcan, navezax)*navezax;
yaxisA	   = yaxisA / norm(yaxisA);
xaxisA      = cross(yaxisA, navezax);


origFrame   = [[xaxisA 0]' [yaxisA 0]' [navezax 0]' [pCA 1]'];

%CBFrame       = OriginalFrame * T([0 0 ibgBL_CACB]);
%
%newCBcoord    = CBFrame([13 14 15]);	
