function results = ikToOffset(atomTypeNo, params, ppChain)
% coords = ikToCoords(atomTypeNo, params, chain) gets ppChain coordinates
% from DH4 parameters, including P1 and P2 points. 
% This is a first prototype.

torad = pi/180;
[ii,jj,kk,mm] = size(params);
coords = chain(:,:,ones(kk,1), ones(mm,1)); % start by copying coords, because first two shouldn't move. 

startFrame = makeFrame(coords(1:3,:));

for l = 1:ll
    for k = 1:kk
        frame = startFrame;
        for i = 1:size(params,1)
            % frame = frame*DH(params(i,:,k,l)); % inline DH for speed
            p = params(i,:,k,l);
            if length(p) < 4
                a = 0;
            else
                a = p(4);
            end
            C = cos(p(1)*torad);
            S = sin(p(1)*torad);
            L = cos(p(2)*torad);
            M = sin(p(2)*torad);
            
            frame = frame*[C -S*L   S*M  a*C; % apply DH
                           S  C*L  -C*M  a*S;
                           0   M     L   p(3);
                           0   0     0   1];
            results(i+2,:,k,l) = frame(1:3,4)'; % save point
        end
    end
end

numAtoms = size(chain,1);
if (numAtoms == 11)
    firstN = 2;
elseif (numAtoms == 12)
    firstN = 1;
else
    error('incorrect chain length');
end
deg = 180/pi;
numBonds = numAtoms-1;

bond = diff(chain); % compute all vectors and normalize
bondLengths = sqrt(sum(bond.^2,2)); % get all lengths
bond = bond ./ bondLengths(:,[1 1 1], :, :); % normalize

% record offset parameter (a) and remove P1->P2 info from bond info
firstCa = 1+mod(firstN,3);
%Cas = find(atomTypeNo(1:end-3) == 2); % list indices of all Calphas except last one.
Cs = firstCa+1:3:numBonds-2;

a = zeros(6,1);
offsetVec = zeros(8,3);
ikChain = chain;
ikBond = bond;

a(firstN:2:5) = bondLengths(Cs);
bondLengths(Cs) = [];
ikChain(Cs,:) = [];
ikBond(Cs,:) = [];
offsetVec(firstCa:2:6,:) = bond(Cs,:); % 
offsetVec(firstCa+1:2:7,:) = bond(Cs,:);

% 11 atoms -> was 10 bonds -> removed 2 -> 8 bonds -> 6 full params to come
% 12 atoms -> was 11 bonds -> removed 3 -> 8 bonds -> 6 full params to come

numIkBonds = length(ikBond);
geom = zeros(numIkBonds-2,4);

for i = 2:(numIkBonds-1)
    geom(i-1,1) = computeDihedral(ikBond(i-1:i+1,:))*deg; % convert to degrees
    geom(i-1,2) = computeBondDHAngle(ikBond(i:i+1,:))*deg;  % convert to degrees    
    
    crossCheck = cross(-ikBond(i,:),ikBond(i+1,:)); % x vector
    if dot(crossCheck, offsetVec(i,:)) < 0
        a(i-1) = -a(i-1);
    end;
end;

geom(:,3) = bondLengths(2:numIkBonds-1);
geom(:,4) = a;
