function result = singleBranch(loop)
% result = singleBranch(loop) keeps only the solutions in loop that look
% like they are from the single branch containing the original.

n = size(loop.coords,1);
kk = size(loop.coords,3);
coords = zeros(n,3,kk);
sc = zeros(n-2,3,kk);
count = zeros(size(loop.solnCount));

coords(:,:,loop.original) = loop.coords(:,:,loop.original,1); % store original, which is soln 1
sc(:,:,loop.original) = loop.sidecoords(:,:,loop.original,1);
count(loop.original) = 1;

for k = loop.original-1:-1:1 % going down
    if loop.solnCount(k)>0
        nn = 1:loop.solnCount(k);
        on = ones(size(nn));
        dist = sum(sum((loop.coords(:,:,k,nn) - coords(:,:,k+1,on)).^2,2),1) ...
            + sum(sum((loop.sidecoords(:,:,k,nn) - sc(:,:,k+1,on)).^2,2),1);
        [v,ind] = min(dist);
        if v > 5
            fprintf('large dist up from %d stops before %d:', loop.original, k); fprintf(' %f', dist);
            break;
        end
        coords(:,:,k) = loop.coords(:,:,k,ind);
        sc(:,:,k) = loop.sidecoords(:,:,k,ind);
        count(k) = 1;
    end
end

for k = loop.original+1:kk % going up
    if loop.solnCount(k)>0
        nn = 1:loop.solnCount(k);
        on = ones(size(nn));
        dist = sum(sum((loop.coords(:,:,k,nn) - coords(:,:,k-1,on)).^2,2),1) ...
            + sum(sum((loop.sidecoords(:,:,k,nn) - sc(:,:,k-1,on)).^2,2),1);
        [v,ind] = min(dist);
        if v > 5
            fprintf('large dist down from %d stops before %d:', loop.original, k); fprintf(' %f', dist);
            break;
        end
        coords(:,:,k) = loop.coords(:,:,k,ind);
        sc(:,:,k) = loop.sidecoords(:,:,k,ind);
        count(k) = 1;
    end
end

ind = count>0; % remove configs with no soln

result.atomTypeNo = loop.atomTypeNo;
result.solnCount = count(ind);
result.coords = coords(:,:,ind);
result.sidecoords = makeSideCoords(result);
%v = result.sidecoords - sc(:,:,ind); norm(v(:)) %%% debugging
result.startAtom = loop.startAtom;
result.wigName = loop.wigName;
result.wigDelta = loop.wigDelta(ind);
result.wigIdeal = loop.wigIdeal;
result.wigPosition = loop.wigPosition;
ind = cumsum(ind); % new indices corresponding to old ks
result.original = ind(loop.original);



