function [i, j, ideal, allowed, wigName] = wigParams(wigLoop, wigName); 
% Determine indices and ideal value of DH3 parameter to wiggle: depends on wigLoop case
% DH3 tables, as build in coords2Params are an (n-1)x3 matrix of [dih, bond ang, bond len] 
% wigName is either a string from the following table, or a number 
% (in which case the string is returned) -- this allows looping over wiggle types

nameTable =             {'tau1', 'beta1', 'beta2', 'tau2', 'beta3', 'beta4', 'tau3', 'beta5', 'beta6', 'pep1', 'pep2', 'pep3', 'nca1', 'cac1', 'c1n2', 'nca2', 'cac2', 'c2n3', 'nca3', 'cac3', 'c3n4'};                
idealValueTable =   [-999 111.2   116.2    121.7    111.2   116.2    121.7    111.2   116.2    121.7    180    180     180     1.47    1.53    1.33    1.47    1.53    1.33    1.47    1.53    1.33];
%allowedDeltaTable = [-999   4       2        2        4       2        2        4       2        2        3      3       3     0.02    0.02    0.02    0.02    0.02    0.02    0.02    0.02    0.02];

allowedDeltaTable = [-999   4       2        2        2       2        2        4       2        2        3      3       3     0.02    0.02    0.02    0.02    0.02    0.02    0.02    0.02    0.02];

wigITable =         [-999   1       2        3        4       5        6        7       8      -999       3      6     -999    1       2       3       4       5       6       7       8      -999; %centralCb
                     -999 -999      1        2        3       4        5        6       7        8        2      5       8   -999      1       2       3       4       5       6       7       8]; %2cb
wigJTable =         [-999   2       2        2        2       2        2        2       2        2        1      1       1     3       3       3       3       3       3       3       3       3]; %table column

looptypeno = strmatch(wigLoop.type, {'cb','2cb'}, 'exact'); % centralCB(default)=1, 2cb=2, ...  
if (isempty(looptypeno))
    looptypeno = 1;
    fprintf('Assuming central Cbeta wiggle: cb');
end
if isnumeric(wigName) && prod(size(wigName))==1 % single number allows iteration
    wigtypeno = 1+wigName;
    wigName = nameTable{wigtypeno};
else
    wigtypeno = 1+strmatch(wigName, nameTable, 'exact');
end
i = wigITable(looptypeno,wigtypeno); % DH3 table row depends on looptype and wigName
if i <= -999
    disp(['In wigParams, invalid wiggle for loop type ' wigLoop.type]);
end;
j = wigJTable(wigtypeno); % DH3 table column depends only on wigName (1=dihedral,2=bond angle,3=length)
ideal = idealValueTable(wigtypeno);
if (j==2), ideal = ideal-180; end % Return bondDHAngle, rather than bond angle
allowed = allowedDeltaTable(wigtypeno);

