function [chain, cnPos] = peptideCNtoP1P2(atomTypeNo, coords);
% [chain, cnPos] = peptideCNtoP1P2(atomTypeNo, coords) 
% We replace all the C & N between Calphas in coords with P1 & P2 to make
% chain and also return the cnPosition multipliers to recover C & N
% positions. 

chain = coords;
kk = size(chain,3);
Cas = find(atomTypeNo(1:end-3) == 2); % list indices of all Calphas except last one.
cnPos = zeros(2,length(Cas), kk); % multipliers for recovering C & N
for k = 1:kk
    for count = 1:length(Cas) %iterate over all pairs of consecutive Calphas
        Ca = Cas(count);
        vec1 = chain(Ca+1,:,k)-chain(Ca,:,k);   % Calpha1 - C
        vec2 = chain(Ca+2,:,k)-chain(Ca+3,:,k); % Calpha2 - N
        vec3 = chain(Ca,:,k)  -chain(Ca+3,:,k); % Calpha2 - Calpha1
        
        dot12 = dot(vec1,vec2);
        A = [-dot(vec1,vec1)  dot12;   -dot12, dot(vec2,vec2)];
        B = [dot(vec1,vec3); dot(vec2,vec3)]; %%% A*t = B;
        t = A\B;
        cnPos(:,count,k) = 1./t; % to recover C = (1 - cnPos)*chain(Ca  ,:) + cnPos*chain(Ca+1,:);
        
        P1 = chain(Ca,:,k) + t(1)*vec1;
        P2 = chain(Ca+3,:,k) + t(2)*vec2;
        
        vecP = P2-P1;
        if (dot(vec1,vecP)> 1e-9) error('p1,p2 calculation not accurate'); end;
        if (dot(vec2,vecP)> 1e-9) error('p1,p2 calculation not accurate'); end;
        
        chain(Ca+1:Ca+2,:,k) = [P1; P2];
    end
end

c = peptideP1P2toCN(atomTypeNo, chain, cnPos); % audit 
if norm(c(:) - coords(:)) > 1e-9
    error('cannot reconstruct params from coords in wiggleLoop');
end
