function [chain, cnPos] = peptideToOffset(atomTypeNo, coords)
% [chain, cnPositions] = peptideToOffset(atomTypeNo, coords) returns coordinates of chain 
% with peptide C and Ns converted to the offset points P1 and P2.  
% It also returns the multiplier cnPos that will retrieve the C or N according to 
% C = (1 - cnPos(count,1))*chain(Ca  ,:) + cnPos(count,1)*chain(Ca+1,:);
% N = (1 - cnPos(count,2))*chain(Ca+3,:) + cnPos(count,2)*chain(Ca+2,:);

Cas = find(atomTypeNo(1:end-3) == 2); % list indices of all Calphas except last one.
chain = coords;
cnPos = zeros(length(Cas), 2, size(chain,3)); % multipliers for reversing
for k = 1:size(chain,3)
    for count = 1:length(Cas) %iterate over all Calphas except last.
        Ca = Cas(count);
        vec1 = chain(Ca+1,:,k)-chain(Ca,:,k);   % Calpha1 - C
        vec2 = chain(Ca+2,:,k)-chain(Ca+3,:,k); % Calpha2 - N
        vec3 = chain(Ca,:,k)  -chain(Ca+3,:,k); % Calpha2 - Calpha1
        
        dot12 = dot(vec1,vec2);
        A = [-dot(vec1,vec1)  dot12;   -dot12, dot(vec2,vec2)];
        B = [dot(vec1,vec3); dot(vec2,vec3)]; %%% A*t = B;
        t = A\B;
        cnPos(count,:,k) = 1./t';
        
        P1 = chain(Ca,:,k) + t(1)*vec1;
        P2 = chain(Ca+3,:,k) + t(2)*vec2;
        
        vecP = P2-P1;
        if (dot(vec1,vecP)> 1e-9) error('p1,p2 calculation not accurate'); end;
        if (dot(vec2,vecP)> 1e-9) error('p1,p2 calculation not accurate'); end;
        
        chain(Ca+1:Ca+2,:,k) = [P1; P2];
    end
end
