function chain = planarize(chain, firstN)
% function chain = planarize(chain, firstn) returns coordinates of a chain 
% with the peptide bonds made planar.  firstn is the index of the row with the first N 
% We average normals to planes through Calpha1 Calpha2 and either C1 or N2,
% and subtract the projections onto this vector

firstCa = 1+mod(firstN,3);
for Ca = firstCa:3:size(chain,1)-3
    R = chain(Ca+3,:)-chain(Ca,:); % Calpha2-Calpha1
    U = cross(chain(Ca+1,:)-chain(Ca,:), R);
    V = cross(chain(Ca+2,:)-chain(Ca+3,:), R); 
    if (dot(U,V) < 0), V = -V; end
    w = (U+V)/norm(U+V); 
    chain(Ca+1,:) = chain(Ca+1,:) - dot(chain(Ca+1,:)-chain(Ca,:),w)*w; % subtract projection onto w
    chain(Ca+2,:) = chain(Ca+2,:) - dot(chain(Ca+2,:)-chain(Ca+3,:),w)*w;
end

    