function [ikParams, ikOriginal, startFrame, targetFrame] = makeIkParams(loop)
% [ikParams, ikOriginal, startFrame, targetFrame] = makeIkParams(loop) takes loop.coords
% and produces ikParams [dihedral, bondDHangle, length, offset, cnMult]
% for the r6solver
% 
% We replace all the C & N between Calphas with P1 & P2 to find offsets.
% Then we drop the P1s. They can be recovered by taking the position before
% applying the offset.  We keep cn multipliers in ikParams(:,5) that allow
% us to recover the replaced C & N positions.
% The ikParams are set so their dihedrals have rotational axes of phis & psis
% (although the angles may be off when there are non-zero offsets).
% bondDHangles are like bond angles -pi, so they are in [-pi,0].
%
% We make the targetFrame so the startFrame can be eye(4).
% We keep the original ikCoords, which is everything before the first and
% after the last Calpha, plus the Calphas & P2s in between. 

chain = loop.coords;
kk = size(chain,3);
% First, we replace C and N with P1 and P2.
[ppChain, cnPos] = peptideCNtoP1P2(loop.atomTypeNo, loop.coords);
c = peptideP1P2toCN(loop.atomTypeNo, ppChain, cnPos);
if norm(loop.coords - c) > 1e-9
    fprintf('error in peptide conversion\n');
    loop.coords - c
end

% Make start & target frames while we still have P1s
startFrame = makeFrame(chain(1:3,:, loop.original)); % either cb:C N Ca or 2cb:N Ca P1. Dihedral is a phi or psi. 
targetFrame = startFrame \ makeFrame(chain(end-2:end,:, loop.original)); % target if we start with eye(4)

% create the ikParams whose dihedrals are just on phi/psi axes. Also chain for ikOriginal.
