function w = wiggleLoop(loop, wigName, nsteps)
% [wigId, wigDelta] = chooseWiggle(loop, wigName,nsteps) 
% Takes the name of the loop DH3 parameter to wiggle and returns a wiggled
% loop, obtained by constructing wiggled DH3 parameters and coordinates, 
% adding a dimension to the original array.
% The main job of this routine is to decide what range of deltas to use.  
% It takes nsteps (default 4) from 0 to the positive allowed range boundary, 
% so it uses 2*nsteps+1 deltas total if the parameter is in the range, 
% and more if the parameter is initially out. 
% It stores wiggle name, deltas, and the index of the zero delta:
%  wigDelta(original)= 0 to preserve the original. 

if nargin<3
    nsteps = 4; % choose how many steps to 0 or range; must be integer.
end
nsteps = round(nsteps);

w = [];
[i, j, ideal, allowed, wigName] = wigParams(loop, wigName); % find out which DH we wiggle
if (i<=0) % bail if the parameters are wrong
    return;
end
w = loop; % start by copying original
w.wigName = wigName;
w.wigPosition = [i j];
w.wigIdeal = ideal;

current = w.params(i,j);
if (current-ideal < -180) 
    current = current+360; % fix angles near -180
end

%  make a range around current & ideal values that includes current at index w.original.
step = allowed/nsteps;  
if current < ideal
    w.wigDelta = current + (-allowed:step:ceil((ideal-current)/allowed+.6)*allowed);
    w.original = nsteps+1;
else
    w.wigDelta = current - fliplr(-allowed:step:ceil((current-ideal)/allowed+.6)*allowed);
    w.original = length(w.wigDelta)-nsteps;
end
%   find(abs(current-w.wigDelta)<1e-4) % make sure we got original right 
%   w.wigDelta = current +(-3:.25:3); % JSS tmp to test with kimberly's
%   w.original = 13; % JSS tmp to test with kimberly's

nDelta = length(w.wigDelta);
w.params = loop.params(:,:,ones(nDelta,1)); % copies of dh3 params, then apply deltas
for k = 1:nDelta
    w.params(i,j,k) = w.wigDelta(k);
end

% convert DH3 parameters to coordinates(:,:,1:nDelta) (loop.coords gives start frame)
w.coords = DHToCoords(w.params, loop.coords); 
params = coords2Params(w.coords); %audit params/coord conversion
d = params(:)-w.params(:); 
d(d < -180) = d(d < -180) + 360;  % fix up angles wrapping around 360.
d(d > 180) = d(d > 180) - 360;
if norm(d) > 1e-9
    error('cannot reconstruct params from coords in wiggleLoop');
end
w.solnCount = ones(nDelta,1); % used in plot routines & makeSideCoords
w.sidecoords = makeSideCoords(w);
%norm(w.coords(:,:,w.original) - loop.coords) % make sure we point to original chain 
