function  writeKinD(loop, filename, buttonname, wigglelist, flag)
% writeKinD(loop, filename, buttonname, wigglelist, flag) writes out a kin
% Writes loop's coords, atomTypeNo, startAtom, resNo
% to the file filename of the form 'name.kin' (write permission is set to 'w' below)
% buttonname is used for the first button of kinemage, 
%       sub-buttons will be mainchain and sidechain)
% wigglelist specifies the wiggles to display; [] = all; 0 = original
%   (need to come back and fix this for branches).
% flag bits default to 0 if omitted indicate whether 
%  flag&1 = suppress backbones for wiggles; draw only for original
%  flag&2 = draw backbone bonds only
%  flag&4 = suppress vertex balls
%  flag&8 = draw derivatives

if nargin < 5
    flag = 0; % default false: don't output derivatives
    if nargin < 4
        wigglelist = [];
    end
end

kk = size(loop.coords,3);
if isempty(wigglelist) 
    wigglelist = 1:kk;
elseif wigglelist == 0
    wigglelist = loop.original;
end

color = 'yellow';  % color for derivative vectors

atomNo = loop.startAtom+(1:length(loop.atomTypeNo))'; % atom numbers in order
kinNum = 1; % 1 b/c write permission is 'w'
fid = fopen(filename, 'w');
fprintf(fid, '@kinemage %g \n', kinNum);

for k = wigglelist
        fprintf(fid, '@group {%s%d } \n', buttonname,k);  
        
        % MAINCHAIN
        fprintf(fid, '@subgroup {mainchain} dominant\n ');
        
        if ~(flag&4) % not suppressing balls
            % plot all N atoms
            ind = find(loop.atomTypeNo==1);
            M = [atomNo(ind) loop.coords(ind,:,k)]; % make a 4xn matrix M whose columns are N atomNo, N coordinates
            fprintf(fid, '@balllist {N} color = blue master = {mainchain} radius = 0.05 \n');
            fprintf(fid, '{ n ala %5d  } %6f, %6f, %6f \n', M');
            
            % plot all Ca atoms
            ind = find(loop.atomTypeNo==2);
            M = [atomNo(ind) loop.coords(ind,:,k)]; % make a 4xn matrix M whose columns are Ca atomNo, Ca coordinates
            fprintf(fid, '@balllist {CA} color = grey master = {mainchain} radius = 0.05 \n');
            fprintf(fid, '{ ca ala %5d  } %6f, %6f, %6f \n', M');
            
            % plot all C atoms  
            ind = find(loop.atomTypeNo==3);
            M = [atomNo(ind) loop.coords(ind,:,k)]; % make a 4xn matrix M whose columns are C atomNo, C coordinates
            fprintf( fid, '@balllist {C} color = grey master = {mainchain} radius = 0.05 \n');
            fprintf(fid, '{ c ala %5d  } %6f, %6f, %6f \n', M');
            
            % plot all O atoms
            ind = find(loop.atomTypeNo(2:end-1)==3); % sidecoords are shifted by one
            M = [atomNo(ind+1) loop.sidecoords(ind,:,k)]; % make a 4xn matrix M whose columns are O atomNo, O coordinates
            fprintf(fid, '@balllist {O} color = red master = {mainchain} radius = 0.05 \n');
            fprintf(fid, '{ o ala %5d  } %6f, %6f, %6f \n', M');
        end % if not suppressing balls
        
        if ~(flag&1) || k == loop.original % suppress backbone for non-original wiggles?
            % plot all N-Ca-C bonds
            M = [atomNo loop.coords(:,:, k)]; % make a 4xn matrix M whose columns are bb atomNo, bb coordinates
            % where bb atom is N,Ca,or C and cycles through this list
            fprintf(fid, '@vectorlist {mc} color = white master = {mainchain} \n');
            % note that the label bb is given in the line below.  This will not affect 
            % viewing in mage, since the atoms balls are what get clicked on (and report 
            % the atom type at the lower left of the screen in Mage).
            fprintf(fid, '{ bb ala %5d  } %6f, %6f, %6f \n', M');        
            
            if ~(flag&2) % backbone plus sidechains?
                % plot all C-O bonds
                ind = 1+find(loop.atomTypeNo(2:end-1)==3); % just get C with sidecoords 
                M = [atomNo(ind) loop.coords(ind,:,k) atomNo(ind) loop.sidecoords(ind-1,:,k)];% make an 8xn matrix M whose columns are C atomNo, C coordinates, O atomNo, O coordinates 
                fprintf( fid, '@vectorlist {co} color= white  master= {mainchain} \n');
                fprintf(fid, '{ c ala %5d  } P  %6f, %6f, %6f { o ala %5d  } L %6f, %6f, %6f \n', M');
                
                % plot all N-H (Hydrogen) bonds
                ind = 1+find(loop.atomTypeNo(2:end-1)==1); % just get N with sidecoords 
                M = [atomNo(ind) loop.coords(ind,:,k) atomNo(ind) loop.sidecoords(ind-1,:,k)];% make an 8xn matrix M whose columns are N atomNo, N coordinates, H atomNo, H coordinates 
                fprintf( fid, '@vectorlist {mc H} color= gray lens master= {mainchain} \n');
                fprintf(fid, '{ n ala %5d  } P  %6f, %6f, %6f { h ala %5d  } L %6f, %6f, %6f \n', M');
            end % backbone plus sidechains?
        end % suppress backbone for non-original?
        
        % SIDECHAIN
        if ~(flag&2) % backbone plus sidechains?
            fprintf(fid, '@subgroup {sidechain} dominant\n');
            
            if ~(flag&4) % not suppressing balls
                ind = find(loop.atomTypeNo(2:end-1)==2); % sidecoords are shifted by one
                M = [atomNo(ind+1) loop.sidecoords(ind,:,k)];% make a 4xn matrix M whose columns are Cb atomNo, Cb coordinates
                fprintf(fid, '@balllist {CB} color = cyan radius = 0.05 \n');
                fprintf(fid, '{ cb ala %5d  }  %6f, %6f, %6f  \n', M');
            end % if not suppressing balls
            
            if ~(flag&1) || k == loop.original % suppress backbone for non-original wiggles?
                ind = 1+find(loop.atomTypeNo(2:end-1)==2); % just get Ca with sidecoords 
                M = [atomNo(ind) loop.coords(ind,:,k) atomNo(ind) loop.sidecoords(ind-1,:,k)];% make a 8xn matrix M whose columns are Ca atomNo, Ca coordinates, Cb atomNo, Cb coordinates 
                fprintf( fid, '@vectorlist {sc} color= cyan  \n');
                fprintf(fid, '{ ca ala %5d  } P  %6f, %6f, %6f { cb ala %5d  } L %6f, %6f, %6f \n', M');
            end % suppress backbone for non-originals
        end %if backbone plus sidechains
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %% below if only place where writeKin and writeKinD differ
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        if (flag&8)
            % Mainchain & Sidechain derivatives mcscDerivs are offset from 
            % [coords; sidecoords]. Formerly called pointDeltaDots
            ind = (1:size(mcscDerivs,1))';
            M = [ ind  loop.mcscDerivs(:,:,k)]; % make a 4xn matrix M whose columns are delta dot No, delta dot coordinates
            fprintf(fid, '@balllist {deltaDots} color = pinktint master = {deltaDots} radius = 0.015 \n');
            fprintf(fid, '{ dd ala %5d  } %6f, %6f, %6f \n', M');
            
            % derivative vectors
            % make an 8xn matrix M whose columns are n,h,ca,cb,c,or o atomNo, correspinding coordinates, 
            % same atomNo, corresponding derivative coordinates (atom coord + deriv direction vector)
            M = [ind [loop.coords(:,:,k); loop.sidecoords(:,:,k)] ind loop.mcscDerivs(:,:,k)];
            fprintf(fid, '@arrowlist {d_%4s} color = %s  master = {d%4s} radius = 0.100 angle = 30.000\n', buttonLabel, color, buttonLabel);
            fprintf(fid, '{ dv ala %5d  } P  %6f, %6f, %6f { dv ala %5d  } A %6f, %6f, %6f \n', M');
        end
end

fclose(fid);
